==> speechanalytic-billing_0.1.4_database.tar.gz: database/mssql/procedures/AccountSubAccountActivate.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[AccountSubAccountActivate] (
	@InstallationId VARCHAR(50) = NULL,
	@AccountId VARCHAR(50) = NULL,
	@SubAccountId VARCHAR(50) = NULL,
	@LastModifiedByUserId VARCHAR(50) = NULL
	)
AS
BEGIN
	-- ESTE SP TIENE POR FINALIDAD DESACTIVAR UNA CUENTA/SUBCUENTA (ENABLED = 0)
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        -- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- VERIFICAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
		IF @InstallationId IS NULL OR @AccountId IS NULL
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABABASE_ERROR_MISSING_PARAMETERS', 16, 16)

		-- VALIDAMOS SI EXISTE LA INSTALLACION 
		IF NOT EXISTS (
			SELECT P.[IsActivated] 
				FROM [dbo].[Platform] P (NOLOCK) 
				WHERE P.[InstallationId] = @InstallationId
		)
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABABASE_ERROR_INSTALLATION_DOES_NOT_EXIST', 16, 16)

		-- VALIDAMOS SI LA INSTALACION ESTA ACTIVDA
		IF NOT EXISTS (
			SELECT P.[IsActivated] 
				FROM [dbo].[Platform] P (NOLOCK) 
				WHERE P.[InstallationId] = @InstallationId
					AND P.[IsActivated] = 1
		)
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABABASE_ERROR_INSTALLATION_IS_NOT_ACTIVATED', 16, 16)

		-- VALIDAMOS SI EXISTE LA CUENTA
		IF NOT EXISTS (
			SELECT 1 
				FROM [dbo].[Account] A (NOLOCK)
				WHERE A.[InstallationId] = @InstallationId 
					AND A.[AccountId] = @AccountId
		)
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABABASE_ERROR_ACCOUNT_DOES_NOT_EXIST', 16, 16)

		-- CONTINUAMOS EL PROCEDIMIENTO DEPENDIENDO SI TENEMOS SUBCUENTAID
		IF @SubAccountId IS NULL
		BEGIN
			-- EN CASO ESTEMOS DESACTIVANDO UNA CUENTA, BUSCAMOS TODOS LOS VCC ASOCIADOS A ELLA

			-- ACTUALIZAMOS EL CAMPO ENABLED DE LA TABLA ACCOUNT
			UPDATE [dbo].[Account]
				SET [Enabled] = 1,
					[LastModifiedByUserId] = @LastModifiedByUserId,
					[LastModifiedDate] = GETUTCDATE()
				WHERE [InstallationId] = @InstallationId 
					AND [AccountId] = @AccountId
					AND [SubAccountId] IS NULL
			-- VERIFICAMOS SI EL REGISTRO FUE ACTUALIZADO
			IF @@ROWCOUNT = 0
				RAISERROR('DATABABASE_ERROR_UPDATE_FAILED', 16, 16)

		END
		ELSE
		BEGIN
			-- EN CASO ESTEMOS DESACTIVANDO UNA SUBCUENTA, SOLO BUSCAMOS UN UNICO VCC

			-- VALIDAMOS SI EXISTE LA SUBCUENTA
			IF NOT EXISTS (
				SELECT 1 
					FROM [dbo].[Account] A (NOLOCK)
					WHERE A.[InstallationId] = @InstallationId 
						AND A.[AccountId] = @AccountId
						AND A.[SubAccountId] = @SubAccountId
			)
				-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
				RAISERROR('DATABABASE_ERROR_SUBACCOUNT_DOES_NOT_EXIST', 16, 16)

			-- ACTUALIZAMOS EL CAMPO ENABLED DE LA TABLA ACCOUNT
			UPDATE [dbo].[Account]
				SET [Enabled] = 1,
					[LastModifiedByUserId] = @LastModifiedByUserId,
					[LastModifiedDate] = GETUTCDATE()
				WHERE [InstallationId] = @InstallationId 
					AND [AccountId] = @AccountId
					AND [SubAccountId] = @SubAccountId 
			-- VERIFICAMOS SI EL REGISTRO FUE ACTUALIZADO
			IF @@ROWCOUNT = 0
				RAISERROR('DATABABASE_ERROR_UPDATE_FAILED', 16, 16)

		END

		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION;

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION;

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speechanalytic-billing_1.0.1_database.tar.gz: database/mssql/procedures/AccountSubAccountActivate.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[AccountSubAccountActivate] (
	@InstallationId VARCHAR(50) = NULL,
	@AccountId VARCHAR(50) = NULL,
	@SubAccountId VARCHAR(50) = NULL,
	@LastModifiedByUserId VARCHAR(50) = NULL
	)
AS
BEGIN
	-- ESTE SP TIENE POR FINALIDAD DESACTIVAR UNA CUENTA/SUBCUENTA (ENABLED = 0)
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        -- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- VERIFICAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
		IF @InstallationId IS NULL OR @AccountId IS NULL
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

		-- VALIDAMOS SI EXISTE LA INSTALLACION 
		IF NOT EXISTS (
			SELECT P.[IsActivated] 
				FROM [dbo].[Platform] P (NOLOCK) 
				WHERE P.[InstallationId] = @InstallationId
		)
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_INSTALLATION_DOES_NOT_EXIST', 16, 16)

		-- VALIDAMOS SI LA INSTALACION ESTA ACTIVDA
		IF NOT EXISTS (
			SELECT P.[IsActivated] 
				FROM [dbo].[Platform] P (NOLOCK) 
				WHERE P.[InstallationId] = @InstallationId
					AND P.[IsActivated] = 1
		)
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_INSTALLATION_IS_NOT_ACTIVATED', 16, 16)

		-- VALIDAMOS SI EXISTE LA CUENTA
		IF NOT EXISTS (
			SELECT 1 
				FROM [dbo].[Account] A (NOLOCK)
				WHERE A.[InstallationId] = @InstallationId 
					AND A.[AccountId] = @AccountId
		)
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_ACCOUNT_DOES_NOT_EXIST', 16, 16)

		-- CONTINUAMOS EL PROCEDIMIENTO DEPENDIENDO SI TENEMOS SUBCUENTAID
		IF @SubAccountId IS NULL
		BEGIN
			-- EN CASO ESTEMOS DESACTIVANDO UNA CUENTA, BUSCAMOS TODOS LOS VCC ASOCIADOS A ELLA

			-- ACTUALIZAMOS EL CAMPO ENABLED DE LA TABLA ACCOUNT
			UPDATE [dbo].[Account]
				SET [Enabled] = 1,
					[LastModifiedByUserId] = @LastModifiedByUserId,
					[LastModifiedDate] = GETUTCDATE()
				WHERE [InstallationId] = @InstallationId 
					AND [AccountId] = @AccountId
					AND [SubAccountId] IS NULL
			-- VERIFICAMOS SI EL REGISTRO FUE ACTUALIZADO
			IF @@ROWCOUNT = 0
				RAISERROR('DATABASE_ERROR_UPDATE_FAILED', 16, 16)

		END
		ELSE
		BEGIN
			-- EN CASO ESTEMOS DESACTIVANDO UNA SUBCUENTA, SOLO BUSCAMOS UN UNICO VCC

			-- VALIDAMOS SI EXISTE LA SUBCUENTA
			IF NOT EXISTS (
				SELECT 1 
					FROM [dbo].[Account] A (NOLOCK)
					WHERE A.[InstallationId] = @InstallationId 
						AND A.[AccountId] = @AccountId
						AND A.[SubAccountId] = @SubAccountId
			)
				-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
				RAISERROR('DATABASE_ERROR_SUBACCOUNT_DOES_NOT_EXIST', 16, 16)

			-- ACTUALIZAMOS EL CAMPO ENABLED DE LA TABLA ACCOUNT
			UPDATE [dbo].[Account]
				SET [Enabled] = 1,
					[LastModifiedByUserId] = @LastModifiedByUserId,
					[LastModifiedDate] = GETUTCDATE()
				WHERE [InstallationId] = @InstallationId 
					AND [AccountId] = @AccountId
					AND [SubAccountId] = @SubAccountId 
			-- VERIFICAMOS SI EL REGISTRO FUE ACTUALIZADO
			IF @@ROWCOUNT = 0
				RAISERROR('DATABASE_ERROR_UPDATE_FAILED', 16, 16)

		END

		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION;

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION;

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
